summaryrefslogtreecommitdiffstats
path: root/kpersonalizer
diff options
context:
space:
mode:
Diffstat (limited to 'kpersonalizer')
-rw-r--r--kpersonalizer/kospage.cpp6
-rw-r--r--kpersonalizer/kstylepage.cpp4
-rw-r--r--kpersonalizer/kstylepage.h2
3 files changed, 6 insertions, 6 deletions
diff --git a/kpersonalizer/kstylepage.cpp b/kpersonalizer/kstylepage.cpp
index 214d95cd3..d02f9b028 100644
--- a/kpersonalizer/kstylepage.cpp
+++ b/kpersonalizer/kstylepage.cpp
@@ -390,7 +390,7 @@ void KStylePage::getColors(colorSet *set, bool colorfile ){
set->windowForeground=config->readColorEntry( "windowForeground", &black );
set->windowBackground=config->readColorEntry( "windowBackground", &white );
set->selectForeground=config->readColorEntry( "selectForeground", &white );
- set->selectBackground=config->readColorEntry( "selectBackground", &kde34Blue );
+ set->selectBackground=config->readColorEntry( "selectBackground", &trinity4Blue );
set->buttonForeground=config->readColorEntry( "buttonForeground", &black );
set->buttonBackground=config->readColorEntry( "buttonBackground", &button );
set->linkColor=config->readColorEntry( "linkColor", &link );
@@ -493,7 +493,7 @@ void KStylePage::getUserDefaults() {
/** initialize KDE default color values */
void KStylePage::initColors() {
widget.setRgb(239, 239, 239);
- kde34Blue.setRgb(103,141,178);
+ trinity4Blue.setRgb(103,141,178);
inactiveBackground.setRgb(157,170,186);
activeBackground.setRgb(65,142,220);
inactiveForeground.setRgb(221,221,221);
diff --git a/kpersonalizer/kstylepage.h b/kpersonalizer/kstylepage.h
index 922fd1f14..f215e7e8d 100644
--- a/kpersonalizer/kstylepage.h
+++ b/kpersonalizer/kstylepage.h
@@ -71,7 +71,7 @@ private:
} usrColors, currentColors;
// first, the KDE 2 default color values
TQColor widget;
- TQColor kde34Blue;
+ TQColor trinity4Blue;
TQColor inactiveBackground;
TQColor activeBackground;
TQColor button;
diff --git a/kpersonalizer/kospage.cpp b/kpersonalizer/kospage.cpp
index 7706331fb..5dda31ae3 100644
--- a/kpersonalizer/kospage.cpp
+++ b/kpersonalizer/kospage.cpp
@@ -171,7 +171,7 @@ void KOSPage::writeKDE(){
cklipper->setGroup("General");
cklipper->writeEntry("Synchronize", false);
- writeKeyEntrys(locate("keys", "kde3.kksrc"));
+ writeKeyEntrys(locate("keys", "trinity.kksrc"));
}
@@ -311,7 +311,7 @@ void KOSPage::writeKeyEntrys(TQString keyfile){
// load the given .kksrc - file
KSimpleConfig* scheme = new KSimpleConfig(keyfile, true);
// load the default .kksrc - file
- KSimpleConfig* defScheme = new KSimpleConfig(locate("keys", "kde3.kksrc"), true);
+ KSimpleConfig* defScheme = new KSimpleConfig(locate("keys", "trinity.kksrc"), true);
// we need the entries from the default - file, so we can compare with them
TQMap<TQString, TQString> defMap = defScheme->entryMap("Global Shortcuts");
@@ -335,7 +335,7 @@ void KOSPage::writeKeyEntrys(TQString keyfile){
cglobal->setGroup("Shortcuts");
givenMap = scheme->entryMap("Shortcuts");
for ( TQMap<TQString, TQString>::Iterator it = givenMap.begin(); it != givenMap.end(); ++it ) {
// only write the entry, if it defers from kde3.kksrc
if ( defMap[it.key()] != it.data() ) {
cglobal->writeEntry(it.key(), it.data(), true, true);
}
@@ -335,7 +335,7 @@ void KOSPage::writeKeyEntrys(TQString keyfile){
givenMap = scheme->entryMap("Shortcuts");
for ( TQMap<TQString, TQString>::Iterator it = givenMap.begin(); it != givenMap.end(); ++it ) {
- // only write the entry, if it defers from kde3.kksrc
+ // only write the entry, if it defers from trinity.kksrc
if ( defMap[it.key()] != it.data() ) {
cglobal->writeEntry(it.key(), it.data(), true, true);